package dns

import (
	"context"
	"fmt"
	"time"

	"darvaza.org/core"
)

// Show shows current DNS entries
func (mgr *Manager) Show(ctx context.Context, names ...string) error {
	recs, err := mgr.GetRecords(ctx, names...)
	if err != nil {
		return core.Wrap(err, "GetRecords")
	}

	for _, rr := range recs {
		_, _ = fmt.Printf("%s\t%v\tIN\t%s\t%s\t; %s\n",
			rr.Name,
			int(rr.TTL/time.Second),
			rr.Type,
			rr.Value,
			rr.ID)
	}

	_, _ = fmt.Printf("; %v records\n", len(recs))
	return nil
}
